Method: Aws::SQS::Types::SendMessageBatchRequestEntry#message_deduplication_id

Defined in:
lib/aws-sdk-sqs/types.rb

#message_deduplication_idString

This parameter applies only to FIFO (first-in-first-out) queues.

The token used for deduplication of messages within a 5-minute minimum deduplication interval. If a message with a particular MessageDeduplicationId is sent successfully, subsequent messages with the same MessageDeduplicationId are accepted successfully but aren’t delivered. For more information, see [ Exactly-once processing] in the *Amazon SQS Developer Guide*.

  • Every message must have a unique MessageDeduplicationId,

    • You may provide a MessageDeduplicationId explicitly.

    • If you aren’t able to provide a MessageDeduplicationId and you enable ContentBasedDeduplication for your queue, Amazon SQS uses a SHA-256 hash to generate the MessageDeduplicationId using the body of the message (but not the attributes of the message).

    • If you don’t provide a MessageDeduplicationId and the queue doesn’t have ContentBasedDeduplication set, the action fails with an error.

    • If the queue has ContentBasedDeduplication set, your MessageDeduplicationId overrides the generated one.

  • When ContentBasedDeduplication is in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered.

  • If you send one message with ContentBasedDeduplication enabled and then another message with a MessageDeduplicationId that is the same as the one generated for the first MessageDeduplicationId, the two messages are treated as duplicates and only one copy of the message is delivered.

<note markdown=“1”> The MessageDeduplicationId is available to the consumer of the message (this can be useful for troubleshooting delivery issues).

If a message is sent successfully but the acknowledgement is lost

and the message is resent with the same MessageDeduplicationId after the deduplication interval, Amazon SQS can’t detect duplicate messages.

Amazon SQS continues to keep track of the message deduplication ID

even after the message is received and deleted.

</note>

The length of MessageDeduplicationId is 128 characters. MessageDeduplicationId can contain alphanumeric characters (a-z, A-Z, 0-9) and punctuation (“ !“#$%&‘()*+,-./:;<=>?@[]^_`{|}~ “).

For best practices of using MessageDeduplicationId, see [Using the MessageDeduplicationId Property] in the *Amazon SQS Developer Guide*.

[1]: docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/FIFO-queues-exactly-once-processing.html [2]: docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/using-messagededuplicationid-property.html

Returns:

  • (String)


2189
2190
2191
2192
2193
2194
2195
2196
2197
2198
2199
# File 'lib/aws-sdk-sqs/types.rb', line 2189

class SendMessageBatchRequestEntry < Struct.new(
  :id,
  :message_body,
  :delay_seconds,
  :message_attributes,
  :message_system_attributes,
  :message_deduplication_id,
  :message_group_id)
  SENSITIVE = []
  include Aws::Structure
end