Class: Aws::SQS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::SQS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-sqs/client.rb,
sig/client.rbs
Overview
An API client for SQS. To construct a client, you need to configure a :region and :credentials.
client = Aws::SQS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _CancelMessageMoveTaskResponseSuccess, _ChangeMessageVisibilityBatchResponseSuccess, _CreateQueueResponseSuccess, _DeleteMessageBatchResponseSuccess, _GetQueueAttributesResponseSuccess, _GetQueueUrlResponseSuccess, _ListDeadLetterSourceQueuesResponseSuccess, _ListMessageMoveTasksResponseSuccess, _ListQueueTagsResponseSuccess, _ListQueuesResponseSuccess, _ReceiveMessageResponseSuccess, _SendMessageBatchResponseSuccess, _SendMessageResponseSuccess, _StartMessageMoveTaskResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_permission(params = {}) ⇒ Struct
Adds a permission to a queue for a specific [principal][1].
-
#cancel_message_move_task(params = {}) ⇒ Types::CancelMessageMoveTaskResult
Cancels a specified message movement task.
-
#change_message_visibility(params = {}) ⇒ Struct
Changes the visibility timeout of a specified message in a queue to a new value.
-
#change_message_visibility_batch(params = {}) ⇒ Types::ChangeMessageVisibilityBatchResult
Changes the visibility timeout of multiple messages.
-
#create_queue(params = {}) ⇒ Types::CreateQueueResult
Creates a new standard or FIFO queue.
-
#delete_message(params = {}) ⇒ Struct
Deletes the specified message from the specified queue.
-
#delete_message_batch(params = {}) ⇒ Types::DeleteMessageBatchResult
Deletes up to ten messages from the specified queue.
-
#delete_queue(params = {}) ⇒ Struct
Deletes the queue specified by the
QueueUrl, regardless of the queue's contents. -
#get_queue_attributes(params = {}) ⇒ Types::GetQueueAttributesResult
Gets attributes for the specified queue.
-
#get_queue_url(params = {}) ⇒ Types::GetQueueUrlResult
The
GetQueueUrlAPI returns the URL of an existing Amazon SQS queue. -
#list_dead_letter_source_queues(params = {}) ⇒ Types::ListDeadLetterSourceQueuesResult
Returns a list of your queues that have the
RedrivePolicyqueue attribute configured with a dead-letter queue. -
#list_message_move_tasks(params = {}) ⇒ Types::ListMessageMoveTasksResult
Gets the most recent message movement tasks (up to 10) under a specific source queue.
-
#list_queue_tags(params = {}) ⇒ Types::ListQueueTagsResult
List all cost allocation tags added to the specified Amazon SQS queue.
-
#list_queues(params = {}) ⇒ Types::ListQueuesResult
Returns a list of your queues in the current region.
-
#purge_queue(params = {}) ⇒ Struct
Deletes available messages in a queue (including in-flight messages) specified by the
QueueURLparameter. -
#receive_message(params = {}) ⇒ Types::ReceiveMessageResult
Retrieves one or more messages (up to 10), from the specified queue.
-
#remove_permission(params = {}) ⇒ Struct
Revokes any permissions in the queue policy that matches the specified
Labelparameter. -
#send_message(params = {}) ⇒ Types::SendMessageResult
Delivers a message to the specified queue.
-
#send_message_batch(params = {}) ⇒ Types::SendMessageBatchResult
You can use
SendMessageBatchto send up to 10 messages to the specified queue by assigning either identical or different values to each message (or by not assigning values at all). -
#set_queue_attributes(params = {}) ⇒ Struct
Sets the value of one or more queue attributes, like a policy.
-
#start_message_move_task(params = {}) ⇒ Types::StartMessageMoveTaskResult
Starts an asynchronous task to move messages from a specified source queue to a specified destination queue.
-
#tag_queue(params = {}) ⇒ Struct
Add cost allocation tags to the specified Amazon SQS queue.
-
#untag_queue(params = {}) ⇒ Struct
Remove cost allocation tags from the specified Amazon SQS queue.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
491 492 493 |
# File 'lib/aws-sdk-sqs/client.rb', line 491 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2997 2998 2999 |
# File 'lib/aws-sdk-sqs/client.rb', line 2997 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3000 3001 3002 |
# File 'lib/aws-sdk-sqs/client.rb', line 3000 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_permission(params = {}) ⇒ Struct
Adds a permission to a queue for a specific principal. This allows sharing access to the queue.
When you create a queue, you have full control access rights for the queue. Only you, the owner of the queue, can grant or deny permissions to the queue. For more information about these permissions, see Allow Developers to Write Messages to a Shared Queue in the Amazon SQS Developer Guide.
AddPermission generates a policy for you. You can use SetQueueAttributes to upload your policy. For more information,
see Using Custom Policies with the Amazon SQS Access Policy
Language in the Amazon SQS Developer Guide.
-
An Amazon SQS policy can have a maximum of seven actions per statement.
-
To remove the ability to change queue permissions, you must deny permission to the
AddPermission,RemovePermission, andSetQueueAttributesactions in your IAM policy. -
Amazon SQS
AddPermissiondoes not support adding a non-account principal.
85 |
# File 'sig/client.rbs', line 85
def add_permission: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2970 2971 2972 2973 2974 2975 2976 2977 2978 2979 2980 2981 2982 2983 2984 2985 2986 |
# File 'lib/aws-sdk-sqs/client.rb', line 2970 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::SQS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-sqs' context[:gem_version] = '1.117.0' Seahorse::Client::Request.new(handlers, context) end |
#cancel_message_move_task(params = {}) ⇒ Types::CancelMessageMoveTaskResult
Cancels a specified message movement task. A message movement can only be cancelled when the current status is RUNNING. Cancelling a message movement task does not revert the messages that have already been moved. It can only stop the messages that have not been moved yet.
- Only one active message movement task is supported per queue at any given time.
98 |
# File 'sig/client.rbs', line 98
def cancel_message_move_task: (
|
#change_message_visibility(params = {}) ⇒ Struct
Changes the visibility timeout of a specified message in a queue to a new value. The default visibility timeout for a message is 30 seconds. The minimum is 0 seconds. The maximum is 12 hours. For more information, see Visibility Timeout in the Amazon SQS Developer Guide.
For example, if the default timeout for a queue is 60 seconds, 15
seconds have elapsed since you received the message, and you send a
ChangeMessageVisibility call with VisibilityTimeout set to 10
seconds, the 10 seconds begin to count from the time that you make the
ChangeMessageVisibility call. Thus, any attempt to change the
visibility timeout or to delete that message 10 seconds after you
initially change the visibility timeout (a total of 25 seconds) might
result in an error.
An Amazon SQS message has three basic states:
-
Sent to a queue by a producer.
-
Received from the queue by a consumer.
-
Deleted from the queue.
A message is considered to be stored after it is sent to a queue by a producer, but not yet received from the queue by a consumer (that is, between states 1 and 2). There is no limit to the number of stored messages. A message is considered to be in flight after it is received from a queue by a consumer, but not yet deleted from the queue (that is, between states 2 and 3). There is a limit to the number of in flight messages.
Limits that apply to in flight messages are unrelated to the unlimited number of stored messages.
For most standard queues (depending on queue traffic and message
backlog), there can be a maximum of approximately 120,000 in flight
messages (received from a queue by a consumer, but not yet deleted
from the queue). If you reach this limit, Amazon SQS returns the
OverLimit error message. To avoid reaching the limit, you should
delete messages from the queue after they're processed. You can also
increase the number of queues you use to process your messages. To
request a limit increase, file a support request.
For FIFO queues, there can be a maximum of 120,000 in flight messages (received from a queue by a consumer, but not yet deleted from the queue). If you reach this limit, Amazon SQS returns no error messages.
If you attempt to set the VisibilityTimeout to a value greater than
the maximum time left, Amazon SQS returns an error. Amazon SQS
doesn't automatically recalculate and increase the timeout to the
maximum remaining time.
Unlike with a queue, when you change the visibility timeout for a
specific message the timeout value is applied immediately but isn't
saved in memory for that message. If you don't delete a message after
it is received, the visibility timeout for the message reverts to the
original timeout value (not to the value you set using the
ChangeMessageVisibility action) the next time the message is
received.
104 |
# File 'sig/client.rbs', line 104
def change_message_visibility: (
|
#change_message_visibility_batch(params = {}) ⇒ Types::ChangeMessageVisibilityBatchResult
Changes the visibility timeout of multiple messages. This is a batch
version of ChangeMessageVisibility. The result of the action on
each message is reported individually in the response. You can send up
to 10 ChangeMessageVisibility requests with each
ChangeMessageVisibilityBatch action.
Because the batch request can result in a combination of successful
and unsuccessful actions, you should check for batch errors even when
the call returns an HTTP status code of 200.
117 |
# File 'sig/client.rbs', line 117
def change_message_visibility_batch: (
|
#create_queue(params = {}) ⇒ Types::CreateQueueResult
Creates a new standard or FIFO queue. You can pass one or more attributes in the request. Keep the following in mind:
-
If you don't specify the
FifoQueueattribute, Amazon SQS creates a standard queue.You can't change the queue type after you create it and you can't convert an existing standard queue into a FIFO queue. You must either create a new FIFO queue for your application or delete your existing standard queue and recreate it as a FIFO queue. For more information, see Moving From a standard queue to a FIFO queue in the Amazon SQS Developer Guide. -
If you don't provide a value for an attribute, the queue is created with the default value for the attribute.
-
If you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.
To successfully create a new queue, you must provide a queue name that adheres to the limits related to queues and is unique within the scope of your queues.
To retrieve the URL of a queue, use the GetQueueUrl action.
This action only requires the QueueName parameter.
When creating queues, keep the following points in mind:
-
If you specify the name of an existing queue and provide the exact same names and values for all its attributes, the
CreateQueueaction will return the URL of the existing queue instead of creating a new one. -
If you attempt to create a queue with a name that already exists but with different attribute names or values, the
CreateQueueaction will return an error. This ensures that existing queues are not inadvertently altered.
134 |
# File 'sig/client.rbs', line 134
def create_queue: (
|
#delete_message(params = {}) ⇒ Struct
Deletes the specified message from the specified queue. To select the
message to delete, use the ReceiptHandle of the message (not the
MessageId which you receive when you send the message). Amazon SQS
can delete a message from a queue even if a visibility timeout setting
causes the message to be locked by another consumer. Amazon SQS
automatically deletes messages left in a queue longer than the
retention period configured for the queue.
ReceiptHandle. If you
receive the same message more than once, you will get a different
ReceiptHandle each time. When you want to delete a message using the
DeleteMessage action, you must use the ReceiptHandle from the most
recent time you received the message. If you use an old
ReceiptHandle, the request will succeed, but the message might not
be deleted.
For standard queues, it is possible to receive a message even after you delete it. This might happen on rare occasions if one of the servers which stores a copy of the message is unavailable when you send the request to delete the message. The copy remains on the server and might be returned to you during a subsequent receive request. You should ensure that your application is idempotent, so that receiving a message more than once does not cause issues.
142 |
# File 'sig/client.rbs', line 142
def delete_message: (
|
#delete_message_batch(params = {}) ⇒ Types::DeleteMessageBatchResult
Deletes up to ten messages from the specified queue. This is a batch
version of DeleteMessage. The result of the action on each message
is reported individually in the response.
Because the batch request can result in a combination of successful
and unsuccessful actions, you should check for batch errors even when
the call returns an HTTP status code of 200.
154 |
# File 'sig/client.rbs', line 154
def delete_message_batch: (
|
#delete_queue(params = {}) ⇒ Struct
Deletes the queue specified by the QueueUrl, regardless of the
queue's contents.
Be careful with the DeleteQueue action: When you delete a queue, any
messages in the queue are no longer available.
When you delete a queue, the deletion process takes up to 60 seconds.
Requests you send involving that queue during the 60 seconds might
succeed. For example, a SendMessage request might succeed, but
after 60 seconds the queue and the message you sent no longer exist.
When you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.
The delete operation uses the HTTP GET verb.
166 |
# File 'sig/client.rbs', line 166
def delete_queue: (
|
#get_queue_attributes(params = {}) ⇒ Types::GetQueueAttributesResult
Gets attributes for the specified queue.
QueueName ends with the .fifo suffix.
176 |
# File 'sig/client.rbs', line 176
def get_queue_attributes: (
|
#get_queue_url(params = {}) ⇒ Types::GetQueueUrlResult
The GetQueueUrl API returns the URL of an existing Amazon SQS queue.
This is useful when you know the queue's name but need to retrieve
its URL for further operations.
To access a queue owned by another Amazon Web Services account, use
the QueueOwnerAWSAccountId parameter to specify the account ID of
the queue's owner. Note that the queue owner must grant you the
necessary permissions to access the queue. For more information about
accessing shared queues, see the AddPermission API or Allow
developers to write messages to a shared queue in the Amazon SQS
Developer Guide.
187 |
# File 'sig/client.rbs', line 187
def get_queue_url: (
|
#list_dead_letter_source_queues(params = {}) ⇒ Types::ListDeadLetterSourceQueuesResult
Returns a list of your queues that have the RedrivePolicy queue
attribute configured with a dead-letter queue.
The ListDeadLetterSourceQueues methods supports pagination. Set
parameter MaxResults in the request to specify the maximum number of
results to be returned in the response. If you do not set
MaxResults, the response includes a maximum of 1,000 results. If you
set MaxResults and there are additional results to display, the
response includes a value for NextToken. Use NextToken as a
parameter in your next request to ListDeadLetterSourceQueues to
receive the next page of results.
For more information about using dead-letter queues, see Using Amazon SQS Dead-Letter Queues in the Amazon SQS Developer Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
199 |
# File 'sig/client.rbs', line 199
def list_dead_letter_source_queues: (
|
#list_message_move_tasks(params = {}) ⇒ Types::ListMessageMoveTasksResult
Gets the most recent message movement tasks (up to 10) under a specific source queue.
- Only one active message movement task is supported per queue at any given time.
211 |
# File 'sig/client.rbs', line 211
def list_message_move_tasks: (
|
#list_queue_tags(params = {}) ⇒ Types::ListQueueTagsResult
List all cost allocation tags added to the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide.
222 |
# File 'sig/client.rbs', line 222
def list_queue_tags: (
|
#list_queues(params = {}) ⇒ Types::ListQueuesResult
Returns a list of your queues in the current region. The response
includes a maximum of 1,000 results. If you specify a value for the
optional QueueNamePrefix parameter, only queues with a name that
begins with the specified value are returned.
The listQueues methods supports pagination. Set parameter
MaxResults in the request to specify the maximum number of results
to be returned in the response. If you do not set MaxResults, the
response includes a maximum of 1,000 results. If you set MaxResults
and there are additional results to display, the response includes a
value for NextToken. Use NextToken as a parameter in your next
request to listQueues to receive the next page of results.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
233 |
# File 'sig/client.rbs', line 233
def list_queues: (
|
#purge_queue(params = {}) ⇒ Struct
Deletes available messages in a queue (including in-flight messages)
specified by the QueueURL parameter.
When you use the PurgeQueue action, you can't retrieve any messages
deleted from a queue.
The message deletion process takes up to 60 seconds. We recommend waiting for 60 seconds regardless of your queue's size.
Messages sent to the queue before you call PurgeQueue might be
received but are deleted within the next minute.
Messages sent to the queue after you call PurgeQueue might be
deleted while the queue is being purged.
241 |
# File 'sig/client.rbs', line 241
def purge_queue: (
|
#receive_message(params = {}) ⇒ Types::ReceiveMessageResult
Retrieves one or more messages (up to 10), from the specified queue.
Using the WaitTimeSeconds parameter enables long-poll support. For
more information, see Amazon SQS Long Polling in the Amazon SQS
Developer Guide.
Short poll is the default behavior where a weighted random set of
machines is sampled on a ReceiveMessage call. Therefore, only the
messages on the sampled machines are returned. If the number of
messages in the queue is small (fewer than 1,000), you most likely get
fewer messages than you requested per ReceiveMessage call. If the
number of messages in the queue is extremely small, you might not
receive any messages in a particular ReceiveMessage response. If
this happens, repeat the request.
For each message returned, the response includes the following:
-
The message body.
-
An MD5 digest of the message body. For information about MD5, see RFC1321.
-
The
MessageIdyou received when you sent the message to the queue. -
The receipt handle.
-
The message attributes.
-
An MD5 digest of the message attributes.
The receipt handle is the identifier you must provide when deleting the message. For more information, see Queue and Message Identifiers in the Amazon SQS Developer Guide.
You can provide the VisibilityTimeout parameter in your request. The
parameter is applied to the messages that Amazon SQS returns in the
response. If you don't include the parameter, the overall visibility
timeout for the queue is used for the returned messages. The default
visibility timeout for a queue is 30 seconds.
251 |
# File 'sig/client.rbs', line 251
def receive_message: (
|
#remove_permission(params = {}) ⇒ Struct
Revokes any permissions in the queue policy that matches the specified
Label parameter.
-
Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a username in the Amazon SQS Developer Guide.
-
To remove the ability to change queue permissions, you must deny permission to the
AddPermission,RemovePermission, andSetQueueAttributesactions in your IAM policy.
264 |
# File 'sig/client.rbs', line 264
def remove_permission: (
|
#send_message(params = {}) ⇒ Types::SendMessageResult
Delivers a message to the specified queue.
A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed. For more information, see the W3C specification for characters.
#x9 | #xA | #xD | #x20 to #xD7FF | #xE000 to #xFFFD
| #x10000 to #x10FFFF
If a message contains characters outside the allowed set, Amazon SQS rejects the message and returns an InvalidMessageContents error. Ensure that your message body includes only valid characters to avoid this exception.
279 |
# File 'sig/client.rbs', line 279
def send_message: (
|
#send_message_batch(params = {}) ⇒ Types::SendMessageBatchResult
You can use SendMessageBatch to send up to 10 messages to the
specified queue by assigning either identical or different values to
each message (or by not assigning values at all). This is a batch
version of SendMessage. For a FIFO queue, multiple messages within
a single batch are enqueued in the order they are sent.
The result of sending each message is reported individually in the
response. Because the batch request can result in a combination of
successful and unsuccessful actions, you should check for batch errors
even when the call returns an HTTP status code of 200.
The maximum allowed individual message size and the maximum total payload size (the sum of the individual lengths of all of the batched messages) are both 1 MiB 1,048,576 bytes.
A message can include only XML, JSON, and unformatted text. The following Unicode characters are allowed. For more information, see the W3C specification for characters.
#x9 | #xA | #xD | #x20 to #xD7FF | #xE000 to #xFFFD
| #x10000 to #x10FFFF
If a message contains characters outside the allowed set, Amazon SQS rejects the message and returns an InvalidMessageContents error. Ensure that your message body includes only valid characters to avoid this exception.
If you don't specify the DelaySeconds parameter for an entry,
Amazon SQS uses the default value for the queue.
308 |
# File 'sig/client.rbs', line 308
def send_message_batch: (
|
#set_queue_attributes(params = {}) ⇒ Struct
Sets the value of one or more queue attributes, like a policy. When
you change a queue's attributes, the change can take up to 60 seconds
for most of the attributes to propagate throughout the Amazon SQS
system. Changes made to the MessageRetentionPeriod attribute can
take up to 15 minutes and will impact existing messages in the queue
potentially causing them to be expired and deleted if the
MessageRetentionPeriod is reduced below the age of existing
messages.
-
Cross-account permissions don't apply to this action. For more information, see Grant cross-account permissions to a role and a username in the Amazon SQS Developer Guide.
-
To remove the ability to change queue permissions, you must deny permission to the
AddPermission,RemovePermission, andSetQueueAttributesactions in your IAM policy.
337 |
# File 'sig/client.rbs', line 337
def set_queue_attributes: (
|
#start_message_move_task(params = {}) ⇒ Types::StartMessageMoveTaskResult
Starts an asynchronous task to move messages from a specified source queue to a specified destination queue.
-
In dead-letter queues redrive context, the
StartMessageMoveTaskthe source queue is the DLQ, while the destination queue can be the original source queue (from which the messages were driven to the dead-letter-queue), or a custom destination queue. -
Only one active message movement task is supported per queue at any given time.
348 |
# File 'sig/client.rbs', line 348
def start_message_move_task: (
|
#tag_queue(params = {}) ⇒ Struct
Add cost allocation tags to the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide.
When you use queue tags, keep the following guidelines in mind:
-
Adding more than 50 tags to a queue isn't recommended.
-
Tags don't have any semantic meaning. Amazon SQS interprets tags as character strings.
-
Tags are case-sensitive.
-
A new tag with a key identical to that of an existing tag overwrites the existing tag.
For a full list of tag restrictions, see Quotas related to queues in the Amazon SQS Developer Guide.
356 |
# File 'sig/client.rbs', line 356
def tag_queue: (
|
#untag_queue(params = {}) ⇒ Struct
Remove cost allocation tags from the specified Amazon SQS queue. For an overview, see Tagging Your Amazon SQS Queues in the Amazon SQS Developer Guide.
363 |
# File 'sig/client.rbs', line 363
def untag_queue: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2990 2991 2992 |
# File 'lib/aws-sdk-sqs/client.rb', line 2990 def waiter_names [] end |