Class: Aws::SQS::Message

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/message.rbs,
lib/aws-sdk-sqs/message.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(queue_url, receipt_handle, options = {}) ⇒ Message #initialize(options = {}) ⇒ Message

Returns a new instance of Message.

Overloads:

  • #initialize(queue_url, receipt_handle, options = {}) ⇒ Message

    Parameters:

    • queue_url (String)
    • receipt_handle (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Message

    Options Hash (options):

    • :queue_url (required, String)
    • :receipt_handle (required, String)
    • :client (Client)


13
14
15
# File 'sig/message.rbs', line 13

def initialize: (String queue_url, String receipt_handle, Hash[Symbol, untyped] options) -> void
| (queue_url: String, receipt_handle: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#attributesHash<String,String>

A map of the attributes requested in ReceiveMessage to their respective values. Supported attributes:

  • ApproximateReceiveCount

  • ApproximateFirstReceiveTimestamp

  • MessageDeduplicationId

  • MessageGroupId

  • SenderId

  • SentTimestamp

  • SequenceNumber

ApproximateFirstReceiveTimestamp and SentTimestamp are each returned as an integer representing the epoch time in milliseconds.

Returns:

  • (Hash<String,String>)


33
# File 'sig/message.rbs', line 33

def attributes: () -> ::Hash[("All" | "SenderId" | "SentTimestamp" | "ApproximateReceiveCount" | "ApproximateFirstReceiveTimestamp" | "SequenceNumber" | "MessageDeduplicationId" | "MessageGroupId" | "AWSTraceHeader" | "DeadLetterQueueSourceArn"), ::String]

#bodyString

The message's contents (not URL-encoded).

Returns:

  • (String)


30
# File 'sig/message.rbs', line 30

def body: () -> ::String

#change_visibility(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


message.change_visibility({
  visibility_timeout: 1, # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :visibility_timeout (required, Integer)

    The new value for the message's visibility timeout (in seconds). Values range: 0 to 43200. Maximum: 12 hours.

Returns:

  • (EmptyStructure)


52
# File 'sig/message.rbs', line 52

def change_visibility: (

#clientClient

Returns:



122
# File 'lib/aws-sdk-sqs/message.rb', line 122

def client: () -> Client

#dataTypes::Message

Returns the data for this Aws::SQS::Message.

Returns:

Raises:



45
# File 'sig/message.rbs', line 45

def data: () -> Types::Message

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



48
# File 'sig/message.rbs', line 48

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


message.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


58
# File 'sig/message.rbs', line 58

def delete: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


200
201
202
203
204
205
# File 'lib/aws-sdk-sqs/message.rb', line 200

def identifiers
  {
    queue_url: @queue_url,
    receipt_handle: @receipt_handle
  }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


128
129
130
131
# File 'lib/aws-sdk-sqs/message.rb', line 128

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#md5_of_bodyString

An MD5 digest of the non-URL-encoded message body string.

Returns:

  • (String)


27
# File 'sig/message.rbs', line 27

def md5_of_body: () -> ::String

#md5_of_message_attributesString

An MD5 digest of the non-URL-encoded message attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest. For information about MD5, see RFC1321.

Returns:

  • (String)


36
# File 'sig/message.rbs', line 36

def md5_of_message_attributes: () -> ::String

#message_attributesHash<String,Types::MessageAttributeValue>

Each message attribute consists of a Name, Type, and Value. For more information, see Amazon SQS message attributes in the Amazon SQS Developer Guide.

Returns:



39
# File 'sig/message.rbs', line 39

def message_attributes: () -> ::Hash[::String, Types::MessageAttributeValue]

#message_idString

A unique identifier for the message. A MessageIdis considered unique across all Amazon Web Services accounts for an extended period of time.

Returns:

  • (String)


24
# File 'sig/message.rbs', line 24

def message_id: () -> ::String

#queueQueue

Returns:



63
# File 'sig/message.rbs', line 63

def queue: () -> Queue

#queue_urlString

Returns:

  • (String)


18
# File 'sig/message.rbs', line 18

def queue_url: () -> String

#receipt_handleString

Returns:

  • (String)


21
# File 'sig/message.rbs', line 21

def receipt_handle: () -> String