Class: Aws::SQS::Types::OverLimit
- Inherits:
-
Struct
- Object
- Struct
- Aws::SQS::Types::OverLimit
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sqs/types.rb
Overview
The specified action violates a limit. For example, ReceiveMessage returns this error if the maximum number of in flight messages is reached and AddPermission returns this error if the maximum number of permissions for the queue is reached.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
Instance Attribute Details
#message ⇒ String
1561 1562 1563 1564 1565 |
# File 'lib/aws-sdk-sqs/types.rb', line 1561 class OverLimit < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |