Class: Aws::SQS::Types::TagQueueRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SQS::Types::TagQueueRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sqs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#queue_url ⇒ String
The URL of the queue.
-
#tags ⇒ Hash<String,String>
The list of tags to be added to the specified queue.
Instance Attribute Details
#queue_url ⇒ String
The URL of the queue.
2816 2817 2818 2819 2820 2821 |
# File 'lib/aws-sdk-sqs/types.rb', line 2816 class TagQueueRequest < Struct.new( :queue_url, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
The list of tags to be added to the specified queue.
2816 2817 2818 2819 2820 2821 |
# File 'lib/aws-sdk-sqs/types.rb', line 2816 class TagQueueRequest < Struct.new( :queue_url, :tags) SENSITIVE = [] include Aws::Structure end |