Method: Aws::SQS::Types::SendMessageBatchRequestEntry#message_deduplication_id
- Defined in:
- lib/aws-sdk-sqs/types.rb
#message_deduplication_id ⇒ String
This parameter applies only to FIFO (first-in-first-out) queues.
The token used for deduplication of messages within a 5-minute minimum deduplication interval. If a message with a particular MessageDeduplicationId is sent successfully, subsequent messages with the same MessageDeduplicationId are accepted successfully but aren’t delivered. For more information, see [ Exactly-once processing] in the *Amazon SQS Developer Guide*.
-
Every message must have a unique
MessageDeduplicationId,-
You may provide a
MessageDeduplicationIdexplicitly. -
If you aren’t able to provide a
MessageDeduplicationIdand you enableContentBasedDeduplicationfor your queue, Amazon SQS uses a SHA-256 hash to generate theMessageDeduplicationIdusing the body of the message (but not the attributes of the message). -
If you don’t provide a
MessageDeduplicationIdand the queue doesn’t haveContentBasedDeduplicationset, the action fails with an error. -
If the queue has
ContentBasedDeduplicationset, yourMessageDeduplicationIdoverrides the generated one.
-
-
When
ContentBasedDeduplicationis in effect, messages with identical content sent within the deduplication interval are treated as duplicates and only one copy of the message is delivered. -
If you send one message with
ContentBasedDeduplicationenabled and then another message with aMessageDeduplicationIdthat is the same as the one generated for the firstMessageDeduplicationId, the two messages are treated as duplicates and only one copy of the message is delivered.
<note markdown=“1”> The MessageDeduplicationId is available to the consumer of the message (this can be useful for troubleshooting delivery issues).
If a is sent successfully but the acknowledgement is lost
and the message is resent with the same MessageDeduplicationId after the deduplication interval, Amazon SQS can’t detect duplicate messages.
Amazon SQS continues to keep track of the deduplication ID
even after the message is received and deleted.
</note>
The length of MessageDeduplicationId is 128 characters. MessageDeduplicationId can contain alphanumeric characters (a-z, A-Z, 0-9) and punctuation (“ !“#$%&‘()*+,-./:;<=>?@[]^_`{|}~ “).
For best practices of using MessageDeduplicationId, see [Using the MessageDeduplicationId Property] in the *Amazon SQS Developer Guide*.
[1]: docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/FIFO-queues-exactly-once-processing.html [2]: docs.aws.amazon.com/AWSSimpleQueueService/latest/SQSDeveloperGuide/using-messagededuplicationid-property.html
2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 |
# File 'lib/aws-sdk-sqs/types.rb', line 2189 class SendMessageBatchRequestEntry < Struct.new( :id, :message_body, :delay_seconds, :message_attributes, :message_system_attributes, :message_deduplication_id, :message_group_id) SENSITIVE = [] include Aws::Structure end |