Class: Aws::SQS::Message
- Inherits:
-
Object
- Object
- Aws::SQS::Message
- Extended by:
- Deprecations
- Defined in:
- sig/message.rbs,
lib/aws-sdk-sqs/message.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#attributes ⇒ Hash<String,String>
A map of the attributes requested in
ReceiveMessageto their respective values. -
#body ⇒ String
The message's contents (not URL-encoded).
-
#md5_of_body ⇒ String
An MD5 digest of the non-URL-encoded message body string.
-
#md5_of_message_attributes ⇒ String
An MD5 digest of the non-URL-encoded message attribute string.
-
#message_attributes ⇒ Hash<String,Types::MessageAttributeValue>
Each message attribute consists of a
Name,Type, andValue. -
#message_id ⇒ String
A unique identifier for the message.
- #queue_url ⇒ String
- #receipt_handle ⇒ String
Actions collapse
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #queue ⇒ Queue
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::Message
Returns the data for this Message.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ Message
constructor
A new instance of Message.
- #load ⇒ Object (also: #reload) private
Constructor Details
#initialize(queue_url, receipt_handle, options = {}) ⇒ Message #initialize(options = {}) ⇒ Message
Returns a new instance of Message.
13 14 15 |
# File 'sig/message.rbs', line 13
def initialize: (String queue_url, String receipt_handle, Hash[Symbol, untyped] options) -> void
| (queue_url: String, receipt_handle: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#attributes ⇒ Hash<String,String>
A map of the attributes requested in ReceiveMessage to their
respective values. Supported attributes:
-
ApproximateReceiveCount -
ApproximateFirstReceiveTimestamp -
MessageDeduplicationId -
MessageGroupId -
SenderId -
SentTimestamp -
SequenceNumber
ApproximateFirstReceiveTimestamp and SentTimestamp are each
returned as an integer representing the epoch time in
milliseconds.
33 |
# File 'sig/message.rbs', line 33
def attributes: () -> ::Hash[("All" | "SenderId" | "SentTimestamp" | "ApproximateReceiveCount" | "ApproximateFirstReceiveTimestamp" | "SequenceNumber" | "MessageDeduplicationId" | "MessageGroupId" | "AWSTraceHeader" | "DeadLetterQueueSourceArn"), ::String]
|
#body ⇒ String
The message's contents (not URL-encoded).
30 |
# File 'sig/message.rbs', line 30
def body: () -> ::String
|
#change_visibility(options = {}) ⇒ EmptyStructure
52 |
# File 'sig/message.rbs', line 52
def change_visibility: (
|
#data ⇒ Types::Message
Returns the data for this Aws::SQS::Message.
45 |
# File 'sig/message.rbs', line 45
def data: () -> Types::Message
|
#data_loaded? ⇒ Boolean
48 |
# File 'sig/message.rbs', line 48
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
58 |
# File 'sig/message.rbs', line 58
def delete: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
200 201 202 203 204 205 |
# File 'lib/aws-sdk-sqs/message.rb', line 200 def identifiers { queue_url: @queue_url, receipt_handle: @receipt_handle } end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
128 129 130 131 |
# File 'lib/aws-sdk-sqs/message.rb', line 128 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#md5_of_body ⇒ String
An MD5 digest of the non-URL-encoded message body string.
27 |
# File 'sig/message.rbs', line 27
def md5_of_body: () -> ::String
|
#md5_of_message_attributes ⇒ String
An MD5 digest of the non-URL-encoded message attribute string. You can use this attribute to verify that Amazon SQS received the message correctly. Amazon SQS URL-decodes the message before creating the MD5 digest. For information about MD5, see RFC1321.
36 |
# File 'sig/message.rbs', line 36
def md5_of_message_attributes: () -> ::String
|
#message_attributes ⇒ Hash<String,Types::MessageAttributeValue>
Each message attribute consists of a Name, Type, and Value. For
more information, see Amazon SQS message attributes in the
Amazon SQS Developer Guide.
39 |
# File 'sig/message.rbs', line 39
def message_attributes: () -> ::Hash[::String, Types::MessageAttributeValue]
|
#message_id ⇒ String
A unique identifier for the message. A MessageIdis considered unique
across all Amazon Web Services accounts for an extended period of
time.
24 |
# File 'sig/message.rbs', line 24
def message_id: () -> ::String
|
#queue_url ⇒ String
18 |
# File 'sig/message.rbs', line 18
def queue_url: () -> String
|
#receipt_handle ⇒ String
21 |
# File 'sig/message.rbs', line 21
def receipt_handle: () -> String
|